//LabPlot: Axis.cc

#include "Axis.h"

//! general axis class
Axis::Axis() {
	l = new Label();
	scale = LINEAR;
	scaling=1;
	shift=0;
	e = true;
	tlrotation=0;
	tlprefix=QString("");
	tlsuffix=QString("");
	tf = QFont(QString("Adobe Times"),12);
	tc = QColor("black");
	tlc = QColor("black");
	bc = QColor("black");
	minorgridcolor = QColor("black");
	majorgridcolor = QColor("black");
	majortics = -1;		// default ("auto")
	minortics = 3;
	majorticse = true;
	minorticse = true;
	atlf = AUTO;
	datetimeformat = "auto";
	tlp = 2;
	ticspos = 0;
	gap = 15;
	majorgridtype = Qt::DashLine;
	minorgridtype = Qt::DotLine;
	majorticswidth = minorticswidth = 1;
	borderwidth = 1;
	majorgridwidth = minorgridwidth = 1;
}

